==> 0.10.1.tar.gz: lib/src/omnibus.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of omnibus;

/// Omnibus controller
///
/// This class manages a single Omnibus context. You should bind messasage
/// handlers to the Omnibus using [bindEventHandler] and [bindRequestHandler].
/// You can publish messages using [publishEvent] and [publishRequest]. You
/// cannot unbind handlers or dynamically change their condition map and you
/// shouldn't have to. A handler should be a stateless, independant part of your
/// program that uses a storage backend only to store data and not to store
/// state. Changing the condition map or unbinding the handler is a state change
/// in some sense. Handlers that are only used temporarily should be replaced by
/// more generalized handlers that exist the entire runtime.
class Omnibus {
  /// Event handlers
  _EventHandlerPool _eventHandlers = new _EventHandlerPool();

  /// Request handlers
  _RequestHandlerPool _requestHandlers = new _RequestHandlerPool();

  /// Bind global event handler to the Omnibus
  ///
  /// You cannot unbind an event handler once binded. You are encouraged to make
  /// the handler as stateless as possible.
  void bindGlobalEventHandler(EventHandler handler) {
    if (handler != null) {
      _eventHandlers.globalHandlers.add(handler);
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Bind global request handler to the Omnibus
  ///
  /// You cannot unbind a request handler once binded. You are encouraged to
  /// make the handler as stateless as possible.
  void bindGlobalRequestHandler(GlobalRequestHandler handler) {
    if (handler != null) {
      _requestHandlers.globalHandlers.add(handler);
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Bind event handler to the Omnibus
  ///
  /// Returns the event handler index.
  void bindEventHandler(
      String omnibusId, Map<String, dynamic> conditions, EventHandler handler) {
    _eventHandlers.insert(omnibusId, conditions, handler);
  }

  /// Bind request handler to the Omnibus
  ///
  /// Returns the request handler index.
  void bindRequestHandler(String omnibusId, Map<String, dynamic> conditions,
      RequestHandler handler) {
    _requestHandlers.insert(omnibusId, conditions, handler);
  }

  /// Publish OmnibusEvent
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<AsyncProcesses<Null>> publishEvent(OmnibusEvent event) {
    return _eventHandlers.publish(event);
  }

  /// Publish OmnibusRequest
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<AsyncResponses> publishRequest(OmnibusRequest request) {
    return _requestHandlers.publish(request);
  }
}

==> 0.11.2.tar.gz: lib/src/omnibus.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

part of omnibus;

/// Omnibus controller
///
/// This class manages a single Omnibus context. You should bind messasage
/// handlers to the Omnibus using [bindEventHandler] and [bindRequestHandler].
/// You can publish messages using [publishEvent] and [publishRequest]. You
/// cannot unbind handlers or dynamically change their condition map and you
/// shouldn't have to. A handler should be a stateless, independant part of your
/// program that uses a storage backend only to store data and not to store
/// state. Changing the condition map or unbinding the handler is a state change
/// in some sense. Handlers that are only used temporarily should be replaced by
/// more generalized handlers that exist the entire runtime.
class Omnibus {
  /// Event handlers
  _EventHandlerPool _eventHandlers = new _EventHandlerPool();

  /// Request handlers
  _RequestHandlerPool _requestHandlers = new _RequestHandlerPool();

  /// Bind global event handler to the Omnibus
  ///
  /// You cannot unbind an event handler once binded. You are encouraged to make
  /// the handler as stateless as possible.
  void bindGlobalEventHandler(EventHandler handler) {
    if (handler != null) {
      _eventHandlers.globalHandlers.add(handler);
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Bind global request handler to the Omnibus
  ///
  /// You cannot unbind a request handler once binded. You are encouraged to
  /// make the handler as stateless as possible.
  void bindGlobalRequestHandler(GlobalRequestHandler handler) {
    if (handler != null) {
      _requestHandlers.globalHandlers.add(handler);
    } else {
      throw new ArgumentError.notNull('handler');
    }
  }

  /// Bind event handler to the Omnibus
  ///
  /// Returns the event handler index.
  void bindEventHandler(String omnibusId, final Map<String, dynamic> conditions,
      EventHandler handler) {
    _eventHandlers.insert(omnibusId, conditions, handler);
  }

  /// Bind request handler to the Omnibus
  ///
  /// Returns the request handler index.
  void bindRequestHandler(String omnibusId,
      final Map<String, dynamic> conditions, RequestHandler handler) {
    _requestHandlers.insert(omnibusId, conditions, handler);
  }

  /// Publish OmnibusEvent
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<AsyncProcesses<Null>> publishEvent(OmnibusEvent event) {
    return _eventHandlers.publish(event);
  }

  /// Publish OmnibusRequest
  ///
  /// This method runs in the future and all handlers are executed
  /// asynchronously.
  Future<AsyncResponses> publishRequest(OmnibusRequest request) {
    return _requestHandlers.publish(request);
  }
}
